comparer

package
v1.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 7, 2024 License: MIT Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func All

func All[E any](slice []E, pred func(elem E) bool) bool

All checks whether all elements of slice satisfy the given predicate.

func Any

func Any[E any](slice []E, pred func(elem E) bool) bool

Any checks whether any element of slice satisfies the given predicate.

Types

This section is empty.

Jump to