package
Version:
v1.3.0
Opens a new window with list of versions in this module.
Published: Dec 7, 2024
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func All[E any](slice []E, pred func(elem E) bool) bool
All checks whether all elements of slice satisfy the given predicate.
func Any[E any](slice []E, pred func(elem E) bool) bool
Any checks whether any element of slice satisfies the given predicate.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.